==> qgis_3.28.9+dfsg.orig.tar.xz: qgis-3.28.9/src/gui/settings/qgssettingsregistrygui.h <==
/***************************************************************************
  qgssettingsregistrygui.h
  --------------------------------------
  Date                 : July 2021
  Copyright            : (C) 2021 by Damiano Lombardi
  Email                : damiano at opengis dot ch
 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef QGSSETTINGSREGISTRYGUI_H
#define QGSSETTINGSREGISTRYGUI_H

#include "qgis_gui.h"
#include "qgis_sip.h"
#include "qgssettingsregistry.h"
#include "qgssettingsentryimpl.h"

/**
 * \ingroup gui
 * \class QgsSettingsRegistryGui
 * \brief QgsSettingsRegistryGui is used for settings introspection and collects all
 * QgsSettingsEntry instances of gui.
 *
 * \since QGIS 3.22
 */
class GUI_EXPORT QgsSettingsRegistryGui : public QgsSettingsRegistry
{
  public:

    /**
     * Constructor for QgsSettingsRegistryGui.
     */
    QgsSettingsRegistryGui();

    /**
     * Destructor for QgsSettingsRegistryGui.
     */
    virtual ~QgsSettingsRegistryGui();

#ifndef SIP_RUN
    //! Settings entry respect screen dpi
    static const inline QgsSettingsEntryBool settingsRespectScreenDPI = QgsSettingsEntryBool( QStringLiteral( "respect_screen_dpi" ), QgsSettings::Prefix::GUI_QGIS, false );

    //! Check for plugin updates automatically on startup
    static const inline QgsSettingsEntryBool settingsAutomaticallyCheckForPluginUpdates = QgsSettingsEntryBool( QStringLiteral( "automatically-check-for-updates" ), QgsSettings::Prefix::PLUGINS, true, QStringLiteral( "Automatically check for plugin updates on startup" ) );

#endif

};

#endif // QGSSETTINGSREGISTRYGUI_H

==> qgis_3.40.5+dfsg.orig.tar.xz: qgis-3.40.5/src/gui/settings/qgssettingsregistrygui.h <==
/***************************************************************************
  qgssettingsregistrygui.h
  --------------------------------------
  Date                 : July 2021
  Copyright            : (C) 2021 by Damiano Lombardi
  Email                : damiano at opengis dot ch
 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/


#ifndef QGSSETTINGSREGISTRYGUI_H
#define QGSSETTINGSREGISTRYGUI_H

#include "qgis_gui.h"
#include "qgssettingsregistry.h"


class QgsSettingsEntryBool;

/**
 * \ingroup gui
 * \class QgsSettingsRegistryGui
 * \brief QgsSettingsRegistryGui is used for settings introspection and collects all
 * QgsSettingsEntry instances of gui.
 *
 * \since QGIS 3.22
 */
Q_NOWARN_DEPRECATED_PUSH
class GUI_EXPORT QgsSettingsRegistryGui : public QgsSettingsRegistry
{
    Q_NOWARN_UNREACHABLE_POP
    // TODO QGIS 4 do not inherit QgsSettingsRegistry
  public:
    QgsSettingsRegistryGui();
    virtual ~QgsSettingsRegistryGui();

#ifndef SIP_RUN
    //! Settings entry respect screen dpi
    static const QgsSettingsEntryBool *settingsRespectScreenDPI;

#endif
};

#endif // QGSSETTINGSREGISTRYGUI_H
